Class: OpenApiSDK::Machines

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/open_api_sdk/machines.rb

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ Machines

Returns a new instance of Machines.



17
18
19
# File 'lib/open_api_sdk/machines.rb', line 17

def initialize(sdk_config)
  @sdk_configuration = sdk_config
end

Instance Method Details

#get_v1_machines(page = nil, page_size = nil, fields_ = nil) ⇒ Object



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/open_api_sdk/machines.rb', line 70

def get_v1_machines(page = nil, page_size = nil, fields_ = nil)
  # get_v1_machines - Retrieve all machines for a user
  # Retrieve details of all machines for the authenticated user, with pagination and optional field selection
  request = ::OpenApiSDK::Operations::GetV1MachinesRequest.new(
    
    page: page,
    page_size: page_size,
    fields_: fields_
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/v1/machines"
  headers = {}
  query_params = Utils.get_query_params(::OpenApiSDK::Operations::GetV1MachinesRequest, request)
  headers['Accept'] = 'application/json;q=1, text/plain;q=0'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    req.params = query_params
    Utils.configure_request_security(req, @sdk_configuration.security) if !@sdk_configuration.nil? && !@sdk_configuration.security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::OpenApiSDK::Operations::GetV1MachinesResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::GetV1MachinesResponseBody)
      res.two_hundred_application_json_object = out
    end
  elsif r.status == 400
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::GetV1MachinesMachinesResponseBody)
      res.four_hundred_application_json_object = out
    end
  elsif r.status == 401
    res.four_hundred_and_one_text_plain_res = r.env.response_body if Utils.match_content_type(content_type, 'text/plain')
  
  end
  res
end

#get_v1_machines_machine_id_(machine_id, ext_urls = nil) ⇒ Object



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/open_api_sdk/machines.rb', line 165

def get_v1_machines_machine_id_(machine_id, ext_urls = nil)
  # get_v1_machines_machine_id_ - Retrieve a specific machine by ID
  # Retrieve details of a specific machine by its ID, with optional workspace details
  request = ::OpenApiSDK::Operations::GetV1MachinesMachineIdRequest.new(
    
    machine_id: machine_id,
    ext_urls: ext_urls
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    ::OpenApiSDK::Operations::GetV1MachinesMachineIdRequest,
    base_url,
    '/v1/machines/{machine_id}',
    request
  )
  headers = {}
  query_params = Utils.get_query_params(::OpenApiSDK::Operations::GetV1MachinesMachineIdRequest, request)
  headers['Accept'] = 'application/json;q=1, text/plain;q=0'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.get(url) do |req|
    req.headers = headers
    req.params = query_params
    Utils.configure_request_security(req, @sdk_configuration.security) if !@sdk_configuration.nil? && !@sdk_configuration.security.nil?
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::OpenApiSDK::Operations::GetV1MachinesMachineIdResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::GetV1MachinesMachineIdResponseBody)
      res.two_hundred_application_json_object = out
    end
  elsif r.status == 400
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::GetV1MachinesMachineIdMachinesResponseBody)
      res.four_hundred_application_json_object = out
    end
  elsif r.status == 401
    res.four_hundred_and_one_text_plain_res = r.env.response_body if Utils.match_content_type(content_type, 'text/plain')
  
  end
  res
end

#post_gpu_event(request) ⇒ Object



23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/open_api_sdk/machines.rb', line 23

def post_gpu_event(request)
  # post_gpu_event - Register a machine event
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/gpu_event"
  headers = {}
  req_content_type, data, form = Utils.serialize_request_body(request, :request, :json)
  headers['content-type'] = req_content_type
  headers['Accept'] = 'application/json;q=1, text/plain;q=0'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.post(url) do |req|
    req.headers = headers
    Utils.configure_request_security(req, @sdk_configuration.security) if !@sdk_configuration.nil? && !@sdk_configuration.security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::OpenApiSDK::Operations::PostGpuEventResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::PostGpuEventResponseBody)
      res.two_hundred_application_json_object = out
    end
  elsif r.status == 401
    res.four_hundred_and_one_text_plain_res = r.env.response_body if Utils.match_content_type(content_type, 'text/plain')
  
  elsif r.status == 500
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::PostGpuEventMachinesResponseBody)
      res.five_hundred_application_json_object = out
    end
  end
  res
end

#post_v1_machines(request) ⇒ Object



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/open_api_sdk/machines.rb', line 117

def post_v1_machines(request)
  # post_v1_machines - Create a new machine
  # Create a new machine with optional default setting
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/v1/machines"
  headers = {}
  req_content_type, data, form = Utils.serialize_request_body(request, :request, :json)
  headers['content-type'] = req_content_type
  headers['Accept'] = 'application/json;q=1, text/plain;q=0'
  headers['user-agent'] = @sdk_configuration.user_agent

  r = @sdk_configuration.client.post(url) do |req|
    req.headers = headers
    Utils.configure_request_security(req, @sdk_configuration.security) if !@sdk_configuration.nil? && !@sdk_configuration.security.nil?
    if form
      req.body = Utils.encode_form(form)
    elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded')
      req.body = URI.encode_www_form(data)
    else
      req.body = data
    end
  end

  content_type = r.headers.fetch('Content-Type', 'application/octet-stream')

  res = ::OpenApiSDK::Operations::PostV1MachinesResponse.new(
    status_code: r.status, content_type: content_type, raw_response: r
  )
  if r.status == 200
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::PostV1MachinesResponseBody)
      res.two_hundred_application_json_object = out
    end
  elsif r.status == 400
    if Utils.match_content_type(content_type, 'application/json')
      out = Utils.unmarshal_complex(r.env.response_body, ::OpenApiSDK::Operations::PostV1MachinesMachinesResponseBody)
      res.four_hundred_application_json_object = out
    end
  elsif r.status == 401
    res.four_hundred_and_one_text_plain_res = r.env.response_body if Utils.match_content_type(content_type, 'text/plain')
  
  end
  res
end